``pygcam.landProtection``
=====================================

This module supports implementation of the :ref:`protect <protect>` sub-command
of :doc:`gcamtool`. It is provided in library form so that it can be used from within
setup programs (or other programs) without having to execute the :doc:`gcamtool` script.

See the documentation for :doc:`landProtection-xml`, the input file used by this subcommand.

API
---

.. automodule:: pygcam.landProtection
   :members:
